#!/usr/bin/python

import time
import datetime
import sys
from pymlab import config

#### Script Arguments ###############################################

if len(sys.argv) != 2:
    sys.stderr.write("Invalid number of arguments.\n")
    sys.stderr.write("Usage: %s PORT ADDRESS\n" % (sys.argv[0], ))
    sys.exit(1)

port    = eval(sys.argv[1])
#### Sensor Configuration ###########################################

cfg = config.Config(
    port = port,
    bus = [
        { "name":"counter", "type":"acount02"},
        { "name":"clkgen", "type":"clkgen01"},
    ],
)
cfg.initialize()

print "Frequency counter readout example \r\n"
fcount = cfg.get_device("counter")
fgen = cfg.get_device("clkgen")
time.sleep(0.5)
frequency = fcount.get_freq()
rfreq = fgen.get_rfreq()
hsdiv = fgen.get_hs_div()
n1 = fgen.get_n1_div()
fdco = 0
fxtal = 0

fgen.set_rfreq(0x2D1E127AD)
fgen.set_hs_div(4)
fgen.set_n1_div(8)

#### Data Logging ###################################################

try:
    with open("temperature.log", "a") as f:
        while True:
            now = datetime.datetime.now()
            if (now.second == 15) or (now.second == 35) or (now.second == 55):
                frequency = fcount.get_freq()
                now = datetime.datetime.now()

            rfreq = fgen.get_rfreq()
            hsdiv = fgen.get_hs_div()
            n1 = fgen.get_n1_div()
            fdco = (frequency/1000000) * hsdiv * n1
            fxtal = fdco / rfreq 

            sys.stdout.write("frequency: " + str(frequency) + " Hz  Time: " + str(now.second))
            sys.stdout.write(" RFREQ: " + str(rfreq) + " HSDIV: " + str(hsdiv) + " N1: " + str(n1))
            sys.stdout.write(" fdco: " + str(fdco) + " fxtal: " + str(fxtal) + "\r\n")
            f.write("%d\t%s\t%.3f\n" % (time.time(), datetime.datetime.now().isoformat(), frequency))

            sys.stdout.flush()
            time.sleep(1)
except KeyboardInterrupt:
    sys.stdout.write("\r\n")
    sys.exit(0)
    f.close()
